import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

# 同花顺概念
SELF_CHOOSE_THS_CONCEPT = 'ths_concept'
# 同花顺行业
SELF_CHOOSE_THS_INDUSTRY = 'ths_industry'
# 开盘啦概念
SELF_CHOOSE_KPL_CONCEPT = 'kpl_concept'



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

# 按照上市时间对股票分类

# 股票类型
stock_type_param = {
    #  上市五个交易日的股票 名字以C开头
    "new_stock": "new",
    # 上市 5个交易日 -365 天的股票
    "sub_stock": "sub",
    # 365 到无穷天的股票
    "normal_stock": "normal",
    # 5-365天的股票
    'sub_stock_max_days': 365,
}





import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
from functools import lru_cache
from mns_common.db.MongodbUtil import MongodbUtil
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.constant.db_name_constant as db_name_constant

mongodb_util = MongodbUtil('27017')


@lru_cache(maxsize=None)
def get_company_info_industry():
    return mongodb_util.find_query_data_choose_field('company_info', {},
                                                     {"_id": 1, "industry": 1, "company_type": 1,
                                                      "ths_concept_name": 1, "ths_concept_code": 1,
                                                      "ths_concept_sync_day": 1, 'sub_stock': 1,
                                                      "first_sw_industry": 1, "second_sw_industry": 1,
                                                      "third_sw_industry": 1, "mv_circulation_ratio": 1,
                                                      "diff_days": 1,
                                                      'em_industry': 1,
                                                      'ths_concept_list_info': 1,
                                                      "kpl_plate_name": 1,
                                                      "kpl_plate_list_info": 1})


@lru_cache(maxsize=None)
def get_company_info_industry_list_date():
    return mongodb_util.find_query_data_choose_field('company_info', {},
                                                     {"_id": 1, "industry": 1, "company_type": 1,
                                                      "ths_concept_name": 1, "ths_concept_code": 1,
                                                      "ths_concept_sync_day": 1, 'sub_stock': 1,
                                                      "first_sw_industry": 1, "second_sw_industry": 1,
                                                      "third_sw_industry": 1, "mv_circulation_ratio": 1,
                                                      "list_date": 1, 'ths_concept_list_info': 1,
                                                      "diff_days": 1, 'em_industry': 1,
                                                      "kpl_plate_name": 1, "kpl_plate_list_info": 1
                                                      })


@lru_cache(maxsize=None)
def get_company_info_industry_mv():
    return mongodb_util.find_query_data_choose_field('company_info', {},
                                                     {"_id": 1, "industry": 1,
                                                      "ths_concept_name": 1, "ths_concept_code": 1,
                                                      "ths_concept_sync_day": 1, 'sub_stock': 1,
                                                      "first_sw_industry": 1, "second_sw_industry": 1,
                                                      "third_sw_industry": 1, "mv_circulation_ratio": 1,
                                                      "diff_days": 1, 'em_industry': 1, 'ths_concept_list_info': 1,
                                                      "flow_mv_sp": 1, "total_mv_sp": 1,
                                                      "kpl_plate_name": 1, "kpl_plate_list_info": 1})


def fix_symbol_industry(realtime_quotes_now_list):
    company_info_industry = get_company_info_industry()
    realtime_quotes_now_list.drop(columns=['industry'], inplace=True)
    realtime_quotes_now_list = realtime_quotes_now_list.set_index(['symbol'], drop=False)

    company_info_industry = company_info_industry.set_index(['_id'], drop=True)

    realtime_quotes_now_list = pd.merge(realtime_quotes_now_list, company_info_industry, how='outer',
                                        left_index=True, right_index=True)

    realtime_quotes_now_list = realtime_quotes_now_list.dropna(inplace=False)
    return realtime_quotes_now_list


# 清除缓存
def company_info_industry_cache_clear():
    get_company_info_industry.cache_clear()
    get_company_info_industry_list_date.cache_clear()


def merge_company_info(df, str_day):
    if data_frame_util.is_empty(df):
        return df
    industry_group_df = get_company_info_industry_list_date()
    industry_group_df = industry_group_df.set_index(['_id'], drop=True)

    df.drop(columns=['industry'], inplace=True)
    df = df.set_index(['symbol'], drop=False)
    df = pd.merge(df, industry_group_df, how='outer',
                  left_index=True, right_index=True)
    df['symbol'] = df.index
    df = df.loc[df['amount'] > 0]
    df = common_service_fun_api.classify_symbol(df)
    df['_id'] = df['symbol'] + "_" + str_day
    df['str_day'] = str_day
    df = common_service_fun_api.total_mv_classification(df)
    return df


# 修改行业信息
def amendment_industry(real_time_quotes_now_init):
    real_time_quotes_now = real_time_quotes_now_init.copy()
    if 'list_date' in real_time_quotes_now.columns:
        industry_group_df = get_company_info_industry()
    else:
        industry_group_df = get_company_info_industry_list_date()
    industry_group_df = industry_group_df.set_index(['_id'], drop=True)
    real_time_quotes_now['em_industry_temp'] = real_time_quotes_now['industry']
    real_time_quotes_now = real_time_quotes_now.loc[~(real_time_quotes_now['em_industry_temp'] == '-')]
    real_time_quotes_now.drop(columns=['industry'], inplace=True)
    real_time_quotes_now = real_time_quotes_now.set_index(['symbol'], drop=False)
    real_time_quotes_now = pd.merge(real_time_quotes_now, industry_group_df, how='outer',
                                    left_index=True, right_index=True)

    real_time_quotes_now.loc[
        real_time_quotes_now["mv_circulation_ratio"].isnull(), ['mv_circulation_ratio']] \
        = 1
    real_time_quotes_now.loc[
        real_time_quotes_now["industry"].isnull(), ['industry']] \
        = real_time_quotes_now["em_industry_temp"]
    real_time_quotes_now.dropna(subset=['symbol'], inplace=True)
    real_time_quotes_now.drop(columns=['em_industry_temp'], inplace=True)

    return real_time_quotes_now


# 允许存在空值的合并
def amendment_industry_exist_na(real_time_quotes_now, symbol_list):
    industry_group_df = get_company_info_industry()
    industry_group_df = industry_group_df.loc[industry_group_df['_id'].isin(symbol_list)]
    industry_group_df = industry_group_df.set_index(['_id'], drop=True)
    real_time_quotes_now.drop(columns=['industry'], inplace=True)
    real_time_quotes_now = real_time_quotes_now.set_index(['symbol'], drop=False)
    real_time_quotes_now = pd.merge(real_time_quotes_now, industry_group_df, how='outer',
                                    left_index=True, right_index=True)
    return real_time_quotes_now


# 获取退市股票代码
@lru_cache(maxsize=None)
def get_de_list_company():
    return list(mongodb_util.find_all_data(db_name_constant.DE_LIST_STOCK)['symbol'])



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

# 开票啦 不选择的精选指数名称
NO_CHOOSE_KPL_INDEX_NAME = [
    '并购重组',
    '三季报增长',  # todo
    '实控人变更',
    '开板次新',
    '高送转',
    '举牌',
    '再融资',
    '股权转让',
    '专精特新',
    '分拆上市预期',
    '年报预增',
    '送转预期',
    '银行',
    '送转填权',
    '业绩增长',
    '中报增长',
    '科创板'
]

# 指数分类
FIRST_INDEX = "first_index"
SUB_INDEX = "sub_index"



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

SYNC_FIELD = [
    'symbol',
    'name',
    'you_zi',
    '_',
    'plate_name_list',
    'now_price',
    'chg',
    'amount',
    'real_exchange',
    'speed',
    'real_flow_mv',
    'main_flow_in',
    'main_flow_out',
    'main_flow_net',
    '_',
    '_',
    '_',
    '_',
    '_',
    # 卖流占比
    'sell_radio',

    'chg_from_chg',
    'quantity_ratio',
    '_',
    'connected_boards',
    'dragon_index',
    'exchange',
    '_',
    '_',
    'closure_funds',
    'max_closure_funds',
    '_',
    '_',
    '_',
    'pct_chg',
    '_',
    '_',
    '_',
    'total_mv',
    'flow_mv',
    'most_relative_name',
    '_',
    '_',
    'last_reason_organ_add',
    '_',

    '_',
    '_',
    '_',
    '_',
    '_',
    '_',

    '_',
    '_',

    '_',
    '_',

    '_',
    '_',
    '_',
    '_',
    '_',
    '_'

]
CHOOSE_FIELD = [
    'symbol',
    'name',
    'you_zi',
    'plate_name_list',
    'now_price',
    'chg',
    'amount',
    'exchange',
    'real_exchange',
    'speed',
    'real_flow_mv',
    'main_flow_in',
    'main_flow_out',
    'main_flow_net',
    # 卖流占比
    'sell_radio',
    'chg_from_chg',
    'quantity_ratio',
    'connected_boards',
    'dragon_index',
    'closure_funds',
    'max_closure_funds',
    'pct_chg',
    'total_mv',
    'flow_mv',
    'most_relative_name',
    'last_reason_organ_add'

]
